#[non_exhaustive]pub enum BackendErrorKind {
Other,
Truncated,
NotImplemented,
Unsupported,
Buffer,
Validation,
InternalInvariant,
}Expand description
Machine-readable class for backend failures surfaced by the facade.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Other
Backend failure has no shared codec classification.
Truncated
Backend failure indicates truncated input.
NotImplemented
Backend failure indicates a planned but unimplemented feature.
Unsupported
Backend failure indicates unsupported input, options, or host capability.
Buffer
Backend failure indicates caller buffer sizing or layout problems.
Validation
Backend failure happened while validating a backend-produced codestream.
InternalInvariant
Failure indicates an internal facade/cache invariant violation.