J2kError

Enum J2kError 

#[non_exhaustive]
pub enum J2kError {
Show 23 variants Buffer(BufferError), Input(InputError), NotImplemented(NotImplemented), Unsupported(Unsupported), Backend(BackendError), NativeDecode { context: &'static str, source: NativeBackendError, }, NativeValidation { context: &'static str, source: NativeBackendError, }, NativeEncode { context: &'static str, source: NativeBackendError, }, NativeResidentEncode { context: &'static str, source: NativeBackendError, }, CodestreamHeader { context: &'static str, source: NativeBackendError, }, BackendComponentPlaneTooShort { component: usize, samples: usize, expected: usize, }, InvalidIccProfile, InternalInvariant { what: &'static str, }, InvalidSamples { what: String, }, RateTargetUnreachable { target: String, best: String, }, InvalidRegion { x: u32, y: u32, w: u32, h: u32, image_w: u32, image_h: u32, }, InvalidBox { offset: usize, what: &'static str, }, MissingRequiredBox { box_type: &'static str, }, InvalidMarker { offset: usize, marker: u8, }, MissingRequiredMarker { marker: &'static str, }, InvalidSiz { what: &'static str, }, InvalidCod { what: &'static str, }, DimensionOverflow { width: u32, height: u32, },
}
Error returned by JPEG 2000 inspect, decode, encode, and recode APIs.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Buffer(BufferError)

Caller-owned buffers were too small or malformed.



Input(InputError)

Input was too short or truncated while parsing.



NotImplemented(NotImplemented)

Requested feature is planned but not implemented.



Unsupported(Unsupported)

Requested input feature or option is unsupported.



Backend(BackendError)

Native backend, accelerator adapter, or backend-output validation failed.



NativeDecode

Heap-free native decoder failure with stable operation context.

Fields

context: &'static str

Decode operation that failed.

source: NativeBackendError

Structured native decoder failure.



NativeValidation

Native decoder failure while validating generated encoder output.

The structured source is retained for diagnostics, but this phase is deliberately not classified as truncated caller input or an unsupported caller request.

Fields

context: &'static str

Validation operation that failed.

source: NativeBackendError

Structured native decoder failure.



NativeEncode

Typed native encoder failure with stable operation context.

Fields

context: &'static str

Encode operation that failed.

source: NativeBackendError

Structured native encoder failure.



NativeResidentEncode

Native resident-encode failure not represented by the shared encoder taxonomy.

Current native variants map to the narrower facade categories above. This source-preserving fallback keeps future variants of the non-exhaustive resident boundary from being reduced to display text.

Fields

context: &'static str

Resident encode operation that failed.

source: NativeBackendError

Structured resident-boundary failure.



CodestreamHeader

Heap-free codestream-header inspection failure.

Fields

context: &'static str

Header operation that failed.

source: NativeBackendError

Structured header parser failure.



BackendComponentPlaneTooShort

A native component plane was shorter than its declared image geometry.

Fields

component: usize

Zero-based component index.

samples: usize

Samples actually returned by the backend.

expected: usize

Minimum samples required by the output geometry.



InvalidIccProfile

The primary JP2 restricted ICC profile is malformed.



InternalInvariant

A facade/cache invariant failed with a static diagnostic.

Fields

what: &'static str

Stable description of the violated invariant.



InvalidSamples

Caller-provided encode samples were malformed.

Fields

what: String

Description of the invalid sample condition.



RateTargetUnreachable

Lossy rate-control search could not satisfy the requested target.

Fields

target: String

Requested rate target.

best: String

Best achievable result observed by the search.



InvalidRegion

Requested region lies outside image bounds.

Fields

x: u32

Region left coordinate.

y: u32

Region top coordinate.

w: u32

Region width.

h: u32

Region height.

image_w: u32

Image width.

image_h: u32

Image height.



InvalidBox

JP2 box structure was invalid.

Fields

offset: usize

Byte offset of the invalid box.

what: &'static str

Description of the invalid box condition.



MissingRequiredBox

Required JP2 box was absent.

Fields

box_type: &'static str

Missing box type.



InvalidMarker

Codestream marker was invalid.

Fields

offset: usize

Byte offset of the invalid marker.

marker: u8

Marker byte following the 0xFF prefix.



MissingRequiredMarker

Required codestream marker was absent.

Fields

marker: &'static str

Missing marker name.



InvalidSiz

SIZ segment was invalid.

Fields

what: &'static str

Description of the invalid SIZ condition.



InvalidCod

COD segment was invalid.

Fields

what: &'static str

Description of the invalid COD condition.



DimensionOverflow

Image dimensions overflowed a size computation.

Fields

width: u32

Image width.

height: u32

Image height.