#[non_exhaustive]pub enum NonRepresentableReason {
UnsupportedComponentCount,
MixedPrecision,
MixedSignedness,
ComponentSubsampling,
PrecisionAboveSixteen,
MixedWaveletTransform,
UnsupportedColor,
}Expand description
Reason an otherwise valid image cannot be represented by the fast batch API.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedComponentCount
Output requires a component count other than Gray, RGB, or RGBA.
MixedPrecision
Components use different significant precisions.
MixedSignedness
Components mix signed and unsigned sample domains.
ComponentSubsampling
At least one component is subsampled.
PrecisionAboveSixteen
At least one component uses more than sixteen significant bits.
MixedWaveletTransform
Tile or component coding-style overrides select different wavelet transforms.
UnsupportedColor
Parsed color metadata is not representable as Gray, RGB, or RGBA.