#[non_exhaustive]pub enum PreparationDepth {
MetadataOnly,
Htj2kOffsetPlan,
ClassicOffsetPlan,
}Expand description
Amount of native execution planning retained by a prepared image.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MetadataOnly
Only inspection and geometry are retained. Decoding reparses native packet structure because the current general parser is borrowing.
Htj2kOffsetPlan
Per-tile Gray/RGB/RGBA HTJ2K packet and code-block geometry is retained;
compressed payloads remain (offset, length) references into the
original EncodedImage::bytes allocation.
ClassicOffsetPlan
Per-tile Gray/RGB/RGBA classic JPEG 2000 packet and code-block
geometry is retained; compressed fragments remain byte ranges into the
original EncodedImage::bytes allocation.