pub struct J2kFileWrapOptions<'a> {
pub payload_kind: CompressedPayloadKind,
pub color: J2kFileColorSpec<'a>,
pub color_specs: &'a [J2kFileColorSpec<'a>],
pub metadata: J2kFileBoxMetadata<'a>,
}Expand description
Options for wrapping a raw JPEG 2000 / HTJ2K codestream as a JP2/JPH file.
Fields
payload_kind: CompressedPayloadKindDesired file wrapper.
color: J2kFileColorSpec<'a>Color metadata to place in the JP2 Header box.
color_specs: &'a [J2kFileColorSpec<'a>]Explicit Colour Specification boxes to place in the JP2 Header box.
When non-empty, these are written in order and Self::color is used
only for legacy single-COLR callers.
metadata: J2kFileBoxMetadata<'a>Optional JP2/JPH file metadata boxes to place in the JP2 Header box.
Implementations
Sourceimpl J2kFileWrapOptions<'_>
impl J2kFileWrapOptions<'_>
Sourceimpl<'a> J2kFileWrapOptions<'a>
impl<'a> J2kFileWrapOptions<'a>
Sourcepub const fn with_color(self, color: J2kFileColorSpec<'a>) -> Self
pub const fn with_color(self, color: J2kFileColorSpec<'a>) -> Self
Return options with explicit color metadata.
Sourcepub const fn with_color_specs(
self,
color_specs: &'a [J2kFileColorSpec<'a>],
) -> Self
pub const fn with_color_specs( self, color_specs: &'a [J2kFileColorSpec<'a>], ) -> Self
Return options with explicit ordered JP2/JPH Colour Specification boxes.
Sourcepub const fn with_metadata(self, metadata: J2kFileBoxMetadata<'a>) -> Self
pub const fn with_metadata(self, metadata: J2kFileBoxMetadata<'a>) -> Self
Return options with explicit JP2/JPH metadata boxes.