pub struct J2kRowDecodeOptions { /* private fields */ }Expand description
Options for bounded J2K row decoding.
Implementations
Sourceimpl J2kRowDecodeOptions
impl J2kRowDecodeOptions
Sourcepub const fn new(max_rows_per_stripe: u32) -> Self
pub const fn new(max_rows_per_stripe: u32) -> Self
Create row decode options with the requested maximum stripe height.
A zero value is normalized to one row.
Sourcepub const fn new_with_max_stripe_bytes(
max_rows_per_stripe: u32,
max_stripe_bytes: usize,
) -> Self
pub const fn new_with_max_stripe_bytes( max_rows_per_stripe: u32, max_stripe_bytes: usize, ) -> Self
Create row decode options with explicit stripe height and byte caps.
Sourcepub const fn with_max_stripe_bytes(self, max_stripe_bytes: usize) -> Self
pub const fn with_max_stripe_bytes(self, max_stripe_bytes: usize) -> Self
Return a copy of these options with an explicit stripe byte cap.
Sourcepub const fn max_rows_per_stripe(self) -> u32
pub const fn max_rows_per_stripe(self) -> u32
Maximum number of decoded rows held per bounded row-decode stripe.
Sourcepub const fn max_stripe_bytes(self) -> usize
pub const fn max_stripe_bytes(self) -> usize
Maximum number of packed bytes held per bounded row-decode stripe.